/*************************************************************************

         name: curt.pl (Chapter 11)
      version: June 18, 1998
  description: User-System discourse interaction
      authors: Patrick Blackburn & Johan Bos
 
*************************************************************************/

:- module(curt,[curt/0]).

:- use_module(readLine,[readLine/1]),
   use_module(comsemOperators),
   use_module(comsemPredicates,[printReadings/1,member/2,compose/3]),
   use_module(betaConversion,[betaConvert/2]),
   use_module(resolvePresup,[projectDrs/1,accommodate/2]),
   use_module(acceptabilityConstraints,[consistentReadings/2,
					informativeReadings/2,
					localConsistentReadings/2,
					localInformativeReadings/2]).

:- [englishGrammar], [englishLexicon], [semMacrosPresupDRT].


/*========================================================================
   Start Curt
========================================================================*/

curt:- 
   curtInput([drs([],[])]).

/*========================================================================
   System requests user
========================================================================*/

curtInput(Readings):-
   readLine(Input),
   curtOutput(Input,Readings).

/*========================================================================
   Systems responds to user
========================================================================*/

curtOutput([],Readings):- !,
   curtSays('Want to tell me something?'),
   curtInput(Readings).

curtOutput([bye],_):- !,
   curtSays('Bye bye!').

curtOutput([new],_):- !,
   curt.

curtOutput([help],Readings):- !,
   nl, write('bye - no more talking'),
   nl, write('drs - prints current readings in DRS-format'),
   nl, write('new - starts a new discourse'), nl,
   curtInput(Readings).

curtOutput([drs],Readings):- !,
   printReadings(Readings),
   curtInput(Readings).

curtOutput(Input,Readings):-   
   d(MergeDrs,Input,[]),!,
   betaConvert(MergeDrs,ReducedDrs),
   getReadings(ReducedDrs,Readings,PotentialReadings),
   consistentReadings(PotentialReadings,ConsistentReadings),
   (
       ConsistentReadings=[],
       curtSays('No! I do not believe that!'),!,
       curtInput(Readings)
   ;
       informativeReadings(ConsistentReadings,InformativeReadings),
       (
	   InformativeReadings=[],
	   curtSays('Yes, I knew that!'),!,
           curtInput(Readings)
       ;
	   curtSays('Ok.'),
           localInformativeReadings(InformativeReadings,LocalInformative),
           localConsistentReadings(LocalInformative,LocalConsistent),
	   (
	       LocalConsistent=[], !,
	       SelectedReadings=InformativeReadings
	   ;
	       SelectedReadings=LocalConsistent
	   ),
           curtInput(SelectedReadings)
       )	   
   ).

curtOutput(_,Readings):-
   curtSays('What?'),
   curtInput(Readings).

/*========================================================================
   Compute all readings
========================================================================*/

getReadings(ProtoDrs,Readings,PotentialReadings):-
   findall((OldDrs,NewDrs),
           (
            member(OldDrs,Readings),
            projectDrs([merge(OldDrs,ProtoDrs),pre([])]-[Drs,pre(P)]),
	    accommodate(P,Drs-NewDrs)
           ),
           PotentialReadings).

/*========================================================================
   Curt's output
========================================================================*/

curtSays(X):- nl, write(X), nl.
