/*************************************************************************

         name: englishGrammarMontague.pl (Chapter 3)
      version: May 25, 1999
  description: Grammar rules for Montague quantifier raising 
      authors: Patrick Blackburn & Johan Bos
 
*************************************************************************/

/*========================================================================
   Grammar Rules
========================================================================*/

d(S) --> s([],S).
d((C@S1)@S2)--> dcoord(D,C), s([],S1), D, d(S2).

s([],NP@lambda(I,S))--> s([bo(NP,I)],S).

s(Q,NP@VP)--> np2([],NP), vp2(Q,VP). 

np2(Q,NP)--> np1(Q,NP).

np1([],Det@Noun)--> det(Det), n2(Noun).
np1([bo(Det@Noun,I)],lambda(P,P@I))--> det(Det), n2(Noun).
np1([],NP)--> pn(NP).
np1([],NP)--> pro(NP).

n2(N)--> n1(N).
n2((C@N1)@N2)--> n1(N1), coord(C), n1(N2).

n1(N)--> noun(N).
n1(PP@N)--> noun(N), pp(PP).
n1(RC@N)--> noun(N), rc(RC).

vp2(Q,VP)--> vp1(Q,VP).

vp1(Q,Mod@VP)--> mod(Mod),  v2(Q,inf,VP).
vp1(Q,VP)--> v2(Q,fin,VP).

v2(Q,fin,Cop@NP)--> cop(Cop), np2(Q,NP).
v2(Q,fin,Neg@(Cop@NP))--> cop(Cop), neg(Neg), np2(Q,NP).

v2(Q,I,V)--> v1(Q,I,V).

v1([],I,V)--> iv(I,V).
v1(Q,I,TV@NP)--> tv(I,TV), np2(Q,NP).

pp(Prep@NP)--> prep(Prep), np2([],NP).

rc(RP@VP)--> relpro(RP), vp2([],VP).

iv(I,IV)--> {lexicon(iv,Sym,Word,I),ivSem(Sym,IV)}, Word.

tv(I,TV)--> {lexicon(tv,Sym,Word,I),tvSem(Sym,TV)}, Word.

cop(TV)--> {lexicon(cop,Sym,Word,_),tvSem(Sym,TV)}, Word.

det(Det)--> {lexicon(det,_,Word,Type),detSem(Type,Det)}, Word.

pn(PN)--> {lexicon(pn,Sym,Word,Gender),pnSem(Sym,Gender,PN)}, Word.

pro(Pro)--> {lexicon(pro,Gender,Word,Type),proSem(Gender,Type,Pro)}, Word.

noun(N)--> {lexicon(noun,Sym,Word,_),nounSem(Sym,N)}, Word.

relpro(RP)--> {lexicon(relpro,_,Word,_),relproSem(RP)}, Word.

prep(Prep)--> {lexicon(prep,Sym,Word,_),prepSem(Sym,Prep)}, Word.

mod(Mod)--> {lexicon(mod,_,Word,Type),modSem(Type,Mod)}, Word.

neg(Neg)--> [not], {modSem(neg,Neg)}.

coord(C)--> {lexicon(coord,_,Word,Type), coordSem(Type,C)}, Word.

dcoord(D,C)--> {lexicon(dcoord,Word,D,Type), dcoordSem(Type,C)}, Word.


