/*************************************************************************

         name: fol2otter.pl (Chapter 11)
      version: June 18, 1998
  description: Translates a formula in otter syntax to standard output
      authors: Patrick Blackburn & Johan Bos
 
*************************************************************************/

:- module(fol2otter,[fol2otter/2]).

/*========================================================================
   Translates formula to otter syntax in file 'temp.in'
========================================================================*/

fol2otter(Axioms,Formula):- 
   tell('temp.in'),
   format('set(auto).~n~n',[]),
   format('clear(print_proofs).~n~n',[]),
   format('clear(print_kept).~n~n',[]),
   format('clear(print_new_demod).~n~n',[]),
   format('clear(print_back_demod).~n~n',[]),
   format('clear(print_back_sub).~n~n',[]),
   format('set(prolog_style_variables).~n~n',[]),
   format('formula_list(usable).~n~n~n',[]),
   printOtterList(Axioms),
   printOtterFormula(Formula),
   format('~nend_of_list.~n',[]), 
   told.

/*========================================================================
   Print a list of Otter formulas
========================================================================*/

printOtterList([]).
printOtterList([X|L]):-
	printOtterFormula(X),
	printOtterList(L).

/*========================================================================
   Print an Otter formula
========================================================================*/

printOtterFormula(F):-
	   \+ \+ (numbervars(F,0,_), printOtter(F,5)),
	   format('.~n',[]).

printOtter(exists(X,Formula),Tab):-
   write('(exists '),write(X),write(' '),!,
   printOtter(Formula,Tab),write(')').

printOtter(forall(X,Formula),Tab):-
   write('(all '),write(X),write(' '),!,
   printOtter(Formula,Tab),write(')').

printOtter(Phi & Psi,Tab):-
   write('('),!,  
   printOtter(Phi,Tab), 
   write(' & '), nl, tab(Tab),
   NewTab is Tab + 5,
   printOtter(Psi,NewTab), write(')').

printOtter(Phi v Psi,Tab):-
   write('('),!,  
   printOtter(Phi,Tab), write(' | '),
   printOtter(Psi,Tab), write(')').

printOtter(Phi > Psi,Tab):-
   write('('),!,  
   printOtter(Phi,Tab), write(' -> '),
   printOtter(Psi,Tab), write(')').

printOtter(~ Phi,Tab):-
   write('-('),!,  
   printOtter(Phi,Tab), write(')').

printOtter(Phi,_):-
   write(Phi).
