/*************************************************************************

         name: mainKellerStorage.pl (Chapter 3)
      version: November 14, 1997
  description: Keller Storage Implementation
      authors: Patrick Blackburn & Johan Bos
 
*************************************************************************/

:- module(mainKellerStorage,[parse/0]).

:- use_module(readLine,[readLine/1]),
   use_module(comsemOperators),
   use_module(comsemPredicates,[printReadings/1,compose/3,append/3]),
   use_module(betaConversion,[betaConvert/2]).

:- [englishGrammar], [englishLexicon], [semMacrosStorage].

/*========================================================================
   Driver Predicate
========================================================================*/

parse:-
   readLine(Sentence),
   s(Sem,Sentence,[]),
   setof(Result,Store^Retrieved^(buildStore(Sem,Store),
                                 sRetrieval(Store,Retrieved),
                                 betaConvert(Retrieved,Result)),
         SemSet),
   printReadings(SemSet).

/*========================================================================
   Quantifier Storage
========================================================================*/

npStorage(Quant,[Arg|Store],[lambda(P,P@X),bo([Quant@Arg|Store],X)]).

/*========================================================================
   Quantifier Retrieval
========================================================================*/

sRetrieval([S],S).

sRetrieval([Sem|Store],S):-
   removeFromStore(bo(Q,X),Store,NewStore),
   sRetrieval([Q@lambda(X,Sem)|NewStore],S).

removeFromStore(bo(O,I),[bo([O|T1],I)|T2],T):- 
   append(T1,T2,T).

removeFromStore(X,[Y|T],[Y|R]):-
   removeFromStore(X,T,R).

/*========================================================================
   Store Constructing
========================================================================*/

buildStore(quant(Quant) @ Store,NewStore):-
   buildStore(Store,[Arg|S]),
   (
    NewStore = [Quant@Arg|S]   
   ;
    npStorage(Quant,[Arg|S],NewStore)
   ).

buildStore([Sem|Store],[Sem|Store]).

buildStore(Store1 @ Store2,[F@A|S]):-
   buildStore(Store1,[F|S1]),
   buildStore(Store2,[A|S2]),
   append(S1,S2,S).

