/*************************************************************************

         name: modelChecker.pl (Chapter 1)
      version: June 19, 1997; March 9, 1999.
  description: A model checker for first-order logic.
      authors: Patrick Blackburn & Johan Bos
 
*************************************************************************/

:- module(modelChecker,[evaluate/2]).

:- use_module(comsemOperators),
   use_module(comsemPredicates,[member/2]),
   use_module(exampleModels,[constant/1,example/2]).

/*========================================================================
   Evaluate a formula in a model
========================================================================*/

evaluate(Formula,Example):-
   example(Example,Model),
   satisfy(Formula,Model).

/*========================================================================
   Semantic Evaluation
========================================================================*/

satisfy(exists(X,Formula),Model):-
   constant(X),
   satisfy(Formula,Model).

satisfy(forall(X,Formula),Model):-
   satisfy(~ exists(X,~ Formula),Model).

satisfy(Formula1 & Formula2,Model):-
   satisfy(Formula1,Model),
   satisfy(Formula2,Model).

satisfy(Formula1 v Formula2,Model):-
   satisfy(Formula1,Model);
   satisfy(Formula2,Model).

satisfy(Formula1 > Formula2,Model):-
   satisfy(Formula2,Model);
   \+ satisfy(Formula1,Model).

satisfy(~ Formula,Model):-
   \+ satisfy(Formula,Model).

satisfy(Formula,Model):-
   member(Formula,Model).

