/*************************************************************************

         name: modelChecker2.pl (Chapter 1)
      version: November 3, 1998
  description: Extention of modelChecker.pl
      authors: Patrick Blackburn & Johan Bos
 
*************************************************************************/

:- module(modelChecker,[evaluate/2]).

:- use_module(comsemOperators),
   use_module(comsemPredicates,[member/2,compose/3]),
   use_module(exampleModels,[constant/1,relation/2,example/2]).

/*========================================================================
   Evaluate a formula in a model
========================================================================*/

evaluate(Formula,Example):-
   sentence([],Formula),
   example(Example,Model),
   satisfy(Formula,Model).

evaluate(Formula,_Example):-
   \+ sentence([],Formula),
   nl,write('Not a wff over the given vocabulary.'),
   nl,write('Cannot be evaluated.'),nl.

/*========================================================================
   Check if a formula is a sentence conform the vocabulary  
========================================================================*/

sentence(_,Var):- 
   var(Var), !, fail.

sentence(Bound,forall(X,Formula)):-
   var(X), 
   sentence([X|Bound],Formula).

sentence(Bound,exists(X,Formula)):-
   var(X),
   sentence([X|Bound],Formula).

sentence(Bound,Formula1 > Formula2):- 
   sentence(Bound,Formula1),
   sentence(Bound,Formula2).

sentence(Bound,Formula1 & Formula2):- 
   sentence(Bound,Formula1),
   sentence(Bound,Formula2).

sentence(Bound,Formula1 v Formula2):- 
   sentence(Bound,Formula1),
   sentence(Bound,Formula2).

sentence(Bound,~ Formula):- 
   sentence(Bound,Formula).

sentence(Bound,Formula):-
   compose(Formula,Symbol,Arguments),
   length(Arguments,Arity),
   relation(Symbol,Arity),
   goodArguments(Bound,Arguments).

/*========================================================================
    Check arguments (must be either constants or bound variables) 
========================================================================*/

goodArguments(_Bound,[]).
goodArguments(Bound,[Arg|Others]):-
   member(Var,Bound),
   Var==Arg, !,
   goodArguments(Bound,Others).
goodArguments(Bound,[Arg|Others]):-
   constant(Arg),
   goodArguments(Bound,Others).

/*========================================================================
   Semantic Evaluation
========================================================================*/

satisfy(exists(X,Formula),Model):-
   \+ \+ (constant(X), satisfy(Formula,Model)).

satisfy(forall(X,Formula),Model):-
   satisfy(~ exists(X,~ Formula),Model).

satisfy(Formula1 & Formula2,Model):-
   satisfy(Formula1,Model),
   satisfy(Formula2,Model).

satisfy(Formula1 v Formula2,Model):-
   satisfy(Formula1,Model);
   satisfy(Formula2,Model).

satisfy(Formula1 > Formula2,Model):-
   satisfy(Formula2,Model);
   \+ satisfy(Formula1,Model).

satisfy(~ Formula,Model):-
   \+ satisfy(Formula,Model).

satisfy(Formula,Model):-
   member(Formula,Model).
