/*************************************************************************

         name: modelDRT.pl (Chapter 7)
      version: July 24, 1997
  description: Model Evaluation for DRSs
      authors: Patrick Blackburn & Johan Bos
 
*************************************************************************/

:- module(modelDRT,[evaluate/2]).

:- use_module(comsemOperators),
   use_module(comsemPredicates,[member/2]),
   use_module(exampleModels,[constant/1,example/2]).

/*========================================================================
   Semantic Interpretation
========================================================================*/

satisfyDrs(drs(Dom,C),Model):-
   assignReferents(Dom),
   satisfyConditions(C,Model).

assignReferents([]).
assignReferents([Referent|Others]):-
   constant(Referent),
   assignReferents(Others).

satisfyConditions([],_).
satisfyConditions([Condition|Others],Model):-
   satisfyCondition(Condition,Model),
   satisfyConditions(Others,Model).

satisfyCondition(~ Drs,Model):-
   \+ satisfyDrs(Drs,Model).

satisfyCondition(Drs1 > Drs2,Model):-
   (
    satisfyDrs(Drs1,Model),
    \+ satisfyDrs(Drs2,Model), 
    !, 
    fail
   ;
    true
   ).

satisfyCondition(Drs1 v Drs2,Model):-
   (
    satisfyDrs(Drs1,Model)
   ;
    satisfyDrs(Drs2,Model)
   ).

satisfyCondition(X=Y,_Model):-
   X=Y.

satisfyCondition(BasicCond,Model):-
   member(BasicCond,Model).

/*========================================================================
   Evaluation
========================================================================*/

evaluate(Drs,Example):-
   example(Example,Model),
   satisfyDrs(Drs,Model).
