/*************************************************************************

         name: nlArgumentation.pl (Chapter 6)
      version: December 16, 1998
  description: Natural Language Argumentation
      authors: Patrick Blackburn & Johan Bos
 
*************************************************************************/

:- module(nlArgumentation,[start/0]).

:- use_module(freeVarTabl,[notatedFormula/3,saturate/2]),
   use_module(readLine,[readLine/1]),
   use_module(comsemOperators),
   use_module(comsemPredicates,[compose/3]),
   use_module(betaConversion,[betaConvert/2]).

:- [englishGrammar], [englishLexicon], [semMacrosLambda].


/*========================================================================

   Putting it together Predicates
   ------------------------------

validArgument(+Argument,+Qdepth) 
   Argument is a list, of which the first element is the conclusion, 
   and the rest of the list the premisses. Try to create a tableau 
   expansion for this argument, that is closed allowing Qdepth 
   applications of the gamma rule. 

premises(?Premises,+NotatedIn,-NotatedOut)
   Turns the formulas in Premises into notated formulas and adds 
   these to NotatedIn, resulting in NotatedOut.

argument(+Premises)
   Asks the user to enter a natural language expression, then 
   translates this into a conclusion C, and checks if the
   Premisses together with  conclusion C are a valid argument, 
   allowing 10 applications of the gamma rule.
 
========================================================================*/

validArgument([Conclusion|Premises],Qdepth):-
   notatedFormula(NotatedConclusion,[],f(Conclusion)),
   premises(Premises,[],NotatedPremises),
   saturate([[NotatedConclusion|NotatedPremises]],Qdepth).

premises([],N,N).
premises([P|Premises],SoFar,NotatedPremises):-
   notatedFormula(NotatedP,[],t(P)),
   premises(Premises,[NotatedP|SoFar],NotatedPremises).

start:- argument([]).

argument(Premises):- 
   readLine(New),
   s(Sem,New,[]),
   betaConvert(Sem,Conclusion),
   (
    validArgument([Conclusion|Premises],10),
    write('valid'), nl
   ;
    write('invalid'), nl
   ),
   argument([Conclusion|Premises]).

