/*************************************************************************

         name: nlQuestions.pl (Chapter 6)
      version: Dec 16, 1998
  description: Combining the model checker and the lambda calculus
               to answer simple natural language questions.
      authors: Patrick Blackburn & Johan Bos
 
*************************************************************************/


:- module(nlQuestions,[query/1,q/3]).

:- use_module(modelChecker2,[evaluate/2]),
   use_module(readLine,[readLine/1]),
   use_module(comsemOperators),
   use_module(comsemPredicates,[compose/3]),
   use_module(betaConversion,[betaConvert/2]).

:- [englishGrammar], [englishLexicon], [semMacrosLambda].

/*========================================================================

   Driver Predicate
   ----------------

query(?Example)
   Tries to translate the user's input Question, into a lambda 
   expression, and evaluate the Sem-part of it in the model named Example. 
   Prints all the answers for which the formula can be evaluated, and 
   then asks again for a new question.

========================================================================*/

query(Example):-
   readLine(Question),
   q(Q,Question,[]),
   betaConvert(Q,lambda(Answer,Sem)),
   evaluate(Sem,Example),
   write(Answer), nl, fail.

query(Example):- 
   query(Example).

/*========================================================================
   Grammar rules for Wh-Questions
========================================================================*/

q(WH@VP)--> wh(WH), vp2(VP).

wh(lambda(P,lambda(X,P@X)))--> [who].

wh(lambda(P,lambda(X,(N@X) & (P@X))))--> [which], n2(N).

