/*************************************************************************

         name: pluggingAlgorithm.pl (Chapter 3)
      version: June 4, 1998
  description: Plugging Algorithm
       author: Patrick Blackburn & Johan Bos
 
*************************************************************************/

:- module(pluggingAlgorithm,[plugHole/4]).

:- use_module(comsemPredicates,[member/2,select/3,variablesInTerm/2]).

/*========================================================================
   Plugging Predicates
========================================================================*/

plugHole(Formula,LFs1-LFs3,Constraints,Scoped):-
   select(Label:Formula,LFs1,LFs2),
   checkConstraints(Label,Constraints,[Formula|Scoped]),
   variablesInTerm(Formula,[]-Arguments),
   checkArguments(Arguments,LFs2-LFs3,Constraints,[Formula|Scoped]).

checkArguments([],LFs-LFs,_,_).

checkArguments([Arg|Rest],LFs1-LFs3,Constraints,Scoped):-
   member(leq(_,Hole),Constraints),
   Hole==Arg, !,
   plugHole(Hole,LFs1-LFs2,Constraints,Scoped),
   checkArguments(Rest,LFs2-LFs3,Constraints,Scoped).

checkArguments([Arg|Rest],LFs1-LFs4,Constraints,Scoped):-
   select(Label:Formula,LFs1,LFs2),
   Label==Arg, !, 
   Formula=Arg, 
   variablesInTerm(Formula,[]-Arguments), 
   checkArguments(Arguments,LFs2-LFs3,Constraints,Scoped),
   checkArguments(Rest,LFs3-LFs4,Constraints,Scoped).

checkArguments([_|Rest],LFs1-LFs2,Constraints,Scoped):-
   checkArguments(Rest,LFs1-LFs2,Constraints,Scoped).

/*========================================================================
   Constraint Checking
========================================================================*/

checkConstraints(_,[],_).

checkConstraints(Label,[leq(L,H)|Constraints],Scoped):-
   Label==L, !, 
   member(Formula,Scoped), Formula==H,
   checkConstraints(Label,Constraints,Scoped).

checkConstraints(Label,[_|Constraints],Scoped):-
   checkConstraints(Label,Constraints,Scoped).

